diff --git a/corsika/detail/framework/stack/CombinedStack.inl b/corsika/detail/framework/stack/CombinedStack.inl
index 4ead3b9b87674bae7011c489ec719049968eade1..0c95ad15e8a8c57eabf1615e07b60c4bb54f3393 100644
--- a/corsika/detail/framework/stack/CombinedStack.inl
+++ b/corsika/detail/framework/stack/CombinedStack.inl
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/core/ParticleProperties.hpp>
 #include <corsika/framework/stack/Stack.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
diff --git a/corsika/detail/framework/stack/SecondaryView.inl b/corsika/detail/framework/stack/SecondaryView.inl
index 5e22a8fef47d4664275cd6bb1dee5e29c0cbe4d7..33160aa08b9b56f09d0929a3abc75a156c818309 100644
--- a/corsika/detail/framework/stack/SecondaryView.inl
+++ b/corsika/detail/framework/stack/SecondaryView.inl
@@ -9,7 +9,7 @@
 #pragma once
 
 #include <corsika/framework/stack/Stack.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <stdexcept>
 #include <vector>
diff --git a/corsika/detail/framework/stack/Stack.inl b/corsika/detail/framework/stack/Stack.inl
index df175bd27f5989f9cda891580a2ab2d990a5381f..30c7c746095e89323e01bbfdae6b8735b99806a4 100644
--- a/corsika/detail/framework/stack/Stack.inl
+++ b/corsika/detail/framework/stack/Stack.inl
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/stack/StackIteratorInterface.hpp>
 
 #include <stdexcept>
diff --git a/corsika/detail/framework/utility/COMBoost.inl b/corsika/detail/framework/utility/COMBoost.inl
index ed6a9c1beedb9b6a256af1e84c17724be9057471..54d1162c327b8ba2f8be9dea485238a0c343ce46 100644
--- a/corsika/detail/framework/utility/COMBoost.inl
+++ b/corsika/detail/framework/utility/COMBoost.inl
@@ -15,7 +15,7 @@
 #include <corsika/framework/geometry/CoordinateSystem.hpp>
 #include <corsika/framework/geometry/FourVector.hpp>
 #include <corsika/framework/geometry/Vector.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 namespace corsika {
 
diff --git a/corsika/detail/media/LayeredSphericalAtmosphereBuilder.inl b/corsika/detail/media/LayeredSphericalAtmosphereBuilder.inl
index f8421ab0672026430310b50030279fc883a84d14..e42310da2c7b13dc51480ff753b836a181557988 100644
--- a/corsika/detail/media/LayeredSphericalAtmosphereBuilder.inl
+++ b/corsika/detail/media/LayeredSphericalAtmosphereBuilder.inl
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/media/FlatExponential.hpp>
 #include <corsika/media/HomogeneousMedium.hpp>
diff --git a/corsika/detail/media/ShowerAxis.inl b/corsika/detail/media/ShowerAxis.inl
index f15e5fb7dc575a314832cb75c7ab71895475b534..1be5d40a66c801299e57c95d1eee3b538839f953 100644
--- a/corsika/detail/media/ShowerAxis.inl
+++ b/corsika/detail/media/ShowerAxis.inl
@@ -7,7 +7,7 @@
  */
 
 #include <corsika/framework/core/PhysicalUnits.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <string>
 
@@ -114,4 +114,4 @@ namespace corsika {
 
   Point const& ShowerAxis::getStart() const { return pointStart_; }
 
-} // namespace corsika
\ No newline at end of file
+} // namespace corsika
diff --git a/corsika/detail/modules/LongitudinalProfile.inl b/corsika/detail/modules/LongitudinalProfile.inl
index f3e46bd5e2dfbbbda5a8c5ecee07534c386c21b0..592f71464ed54d75cc7a20c30f43d08cd59384ad 100644
--- a/corsika/detail/modules/LongitudinalProfile.inl
+++ b/corsika/detail/modules/LongitudinalProfile.inl
@@ -7,7 +7,7 @@
  */
 
 #include <corsika/framework/core/ParticleProperties.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/modules/LongitudinalProfile.hpp>
 
@@ -71,4 +71,4 @@ namespace corsika {
       f << std::endl;
     }
   }
-} // namespace corsika
\ No newline at end of file
+} // namespace corsika
diff --git a/corsika/detail/modules/conex/CONEXhybrid.inl b/corsika/detail/modules/conex/CONEXhybrid.inl
index 53df3d4d36dd406b51c52c9bebd4185746adfe2d..f722440d304e20a75c83a73e975fe06c1b15b36e 100644
--- a/corsika/detail/modules/conex/CONEXhybrid.inl
+++ b/corsika/detail/modules/conex/CONEXhybrid.inl
@@ -6,7 +6,7 @@
  * the license.
  */
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/modules/conex/CONEXhybrid.hpp>
 #include <corsika/modules/conex/CONEX_f.hpp>
 #include <corsika/framework/random/RNGManager.hpp>
@@ -291,4 +291,4 @@ namespace corsika {
     fitout.close();
   }
 
-} // namespace corsika
\ No newline at end of file
+} // namespace corsika
diff --git a/corsika/detail/modules/energy_loss/BetheBlochPDG.inl b/corsika/detail/modules/energy_loss/BetheBlochPDG.inl
index c530afe13c8fc54a6f1b7d76df272ce0e5e0d6b5..fbde1729cf7964c153674c193bded83c416ce03b 100644
--- a/corsika/detail/modules/energy_loss/BetheBlochPDG.inl
+++ b/corsika/detail/modules/energy_loss/BetheBlochPDG.inl
@@ -14,7 +14,7 @@
 #include <corsika/setup/SetupTrajectory.hpp>
 
 #include <corsika/framework/geometry/Line.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <cmath>
 #include <fstream>
diff --git a/corsika/detail/modules/proposal/ContinuousProcess.inl b/corsika/detail/modules/proposal/ContinuousProcess.inl
index e9cb61c0270650f6b62a0566d9b7e075781ec6d9..16d419b0be200bb0d65b8748770818491d5e53b2 100644
--- a/corsika/detail/modules/proposal/ContinuousProcess.inl
+++ b/corsika/detail/modules/proposal/ContinuousProcess.inl
@@ -13,7 +13,7 @@
 #include <corsika/modules/proposal/Interaction.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/utility/COMBoost.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/setup/SetupEnvironment.hpp>
 #include <corsika/setup/SetupStack.hpp>
diff --git a/corsika/detail/modules/sibyll/NuclearInteraction.inl b/corsika/detail/modules/sibyll/NuclearInteraction.inl
index 1aad71beff0f3fd97f1ed8645a959402819b7bc7..4470ea28a8b1e2f504711346790b67bf2342370e 100644
--- a/corsika/detail/modules/sibyll/NuclearInteraction.inl
+++ b/corsika/detail/modules/sibyll/NuclearInteraction.inl
@@ -16,7 +16,7 @@
 #include <corsika/framework/geometry/FourVector.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/utility/COMBoost.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/setup/SetupEnvironment.hpp>
 #include <corsika/setup/SetupStack.hpp>
diff --git a/corsika/detail/modules/tracking/Intersect.inl b/corsika/detail/modules/tracking/Intersect.inl
index 9c30ff87d1156bfdfd7c1a94d2ba32b4b771c73b..fef16a955801992b636516605eec118d24fd3a04 100644
--- a/corsika/detail/modules/tracking/Intersect.inl
+++ b/corsika/detail/modules/tracking/Intersect.inl
@@ -9,7 +9,7 @@
 #pragma once
 
 #include <corsika/framework/core/PhysicalUnits.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/geometry/Intersections.hpp>
 
 #include <limits>
diff --git a/corsika/detail/modules/tracking/TrackingLeapFrogCurved.inl b/corsika/detail/modules/tracking/TrackingLeapFrogCurved.inl
index 3ddd6d6cee6c2129e1a2cdfc83e038538b4bfd3e..8545d2bbdc434501070f6a1b11232dc93184c47d 100644
--- a/corsika/detail/modules/tracking/TrackingLeapFrogCurved.inl
+++ b/corsika/detail/modules/tracking/TrackingLeapFrogCurved.inl
@@ -18,7 +18,7 @@
 #include <corsika/framework/core/ParticleProperties.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/utility/QuarticSolver.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/modules/tracking/Intersect.hpp>
 
 #include <type_traits>
diff --git a/corsika/detail/modules/tracking/TrackingStraight.inl b/corsika/detail/modules/tracking/TrackingStraight.inl
index 33ad57ede7e77e12fe826c5258a31e824fad48b3..2c284b4d01dddc3be3322dc305a84f6f836bd5e5 100644
--- a/corsika/detail/modules/tracking/TrackingStraight.inl
+++ b/corsika/detail/modules/tracking/TrackingStraight.inl
@@ -15,7 +15,7 @@
 #include <corsika/framework/geometry/Vector.hpp>
 #include <corsika/framework/geometry/StraightTrajectory.hpp>
 #include <corsika/framework/geometry/Intersections.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/modules/tracking/Intersect.hpp>
 
 #include <type_traits>
diff --git a/corsika/detail/stack/NuclearStackExtension.inl b/corsika/detail/stack/NuclearStackExtension.inl
index b1fe9ba1c1d9f2df58a1fd79d0c1d7d1b0cb5b2e..728647ca0bfc5ea89738946ccdef9c36cda31ce2 100644
--- a/corsika/detail/stack/NuclearStackExtension.inl
+++ b/corsika/detail/stack/NuclearStackExtension.inl
@@ -13,7 +13,7 @@
 #include <corsika/framework/stack/Stack.hpp>
 #include <corsika/framework/geometry/Point.hpp>
 #include <corsika/framework/geometry/Vector.hpp>
-#include <corsika/stack/SimpleStack.hpp>
+#include <corsika/stack/VectorStack.hpp>
 
 #include <algorithm>
 #include <tuple>
diff --git a/corsika/detail/stack/SimpleStack.inl b/corsika/detail/stack/VectorStack.inl
similarity index 90%
rename from corsika/detail/stack/SimpleStack.inl
rename to corsika/detail/stack/VectorStack.inl
index 4b0e13ecb29592049deb275bf37b1ecddc7b4c48..44384a131f8733711c52c72baff2d471af87da79 100644
--- a/corsika/detail/stack/SimpleStack.inl
+++ b/corsika/detail/stack/VectorStack.inl
@@ -43,7 +43,7 @@ namespace corsika {
     this->setTime(std::get<4>(v));
   }
 
-  inline void SimpleStackImpl::clear() {
+  inline void VectorStackImpl::clear() {
     dataPID_.clear();
     dataE_.clear();
     momentum_.clear();
@@ -51,7 +51,7 @@ namespace corsika {
     time_.clear();
   }
 
-  inline void SimpleStackImpl::copy(size_t i1, size_t i2) {
+  inline void VectorStackImpl::copy(size_t i1, size_t i2) {
     dataPID_[i2] = dataPID_[i1];
     dataE_[i2] = dataE_[i1];
     momentum_[i2] = momentum_[i1];
@@ -59,7 +59,7 @@ namespace corsika {
     time_[i2] = time_[i1];
   }
 
-  inline void SimpleStackImpl::swap(size_t i1, size_t i2) {
+  inline void VectorStackImpl::swap(size_t i1, size_t i2) {
     std::swap(dataPID_[i2], dataPID_[i1]);
     std::swap(dataE_[i2], dataE_[i1]);
     std::swap(momentum_[i2], momentum_[i1]);
@@ -67,7 +67,7 @@ namespace corsika {
     std::swap(time_[i2], time_[i1]);
   }
 
-  inline void SimpleStackImpl::incrementSize() {
+  inline void VectorStackImpl::incrementSize() {
     dataPID_.push_back(Code::Unknown);
     dataE_.push_back(0 * electronvolt);
 
@@ -80,7 +80,7 @@ namespace corsika {
     time_.push_back(0 * second);
   }
 
-  inline void SimpleStackImpl::decrementSize() {
+  inline void VectorStackImpl::decrementSize() {
     if (dataE_.size() > 0) {
       dataPID_.pop_back();
       dataE_.pop_back();
diff --git a/corsika/framework/core/Cascade.hpp b/corsika/framework/core/Cascade.hpp
index d7d3bbe0806ebad30a91400c416fa67346abd969..64c4c065e01fd6bf08bf394605c04285a914c09a 100644
--- a/corsika/framework/core/Cascade.hpp
+++ b/corsika/framework/core/Cascade.hpp
@@ -16,7 +16,7 @@
 #include <corsika/framework/random/UniformRealDistribution.hpp>
 #include <corsika/framework/stack/SecondaryView.hpp>
 #include <corsika/media/Environment.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 /*  see Issue 161, we need to include SetupStack only because we need
     to globally define StackView. This is clearly not nice and should
diff --git a/corsika/framework/logging/Logging.hpp b/corsika/framework/core/Logging.hpp
similarity index 100%
rename from corsika/framework/logging/Logging.hpp
rename to corsika/framework/core/Logging.hpp
diff --git a/corsika/framework/geometry/CoordinateSystem.hpp b/corsika/framework/geometry/CoordinateSystem.hpp
index 32fbba52eab658d46db63867f53307a634d73174..ed9c8184853e61c9d19d102d2543a79d7806d7fc 100644
--- a/corsika/framework/geometry/CoordinateSystem.hpp
+++ b/corsika/framework/geometry/CoordinateSystem.hpp
@@ -14,7 +14,7 @@
 
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/geometry/QuantityVector.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <Eigen/Dense>
 #include <stdexcept>
diff --git a/corsika/framework/random/RNGManager.hpp b/corsika/framework/random/RNGManager.hpp
index 9fb217f24d710724383b77c9971de74158d79cde..2dd6160e993d5a39b2aeb35f62be874047372cf3 100644
--- a/corsika/framework/random/RNGManager.hpp
+++ b/corsika/framework/random/RNGManager.hpp
@@ -14,7 +14,7 @@
 #include <string>
 
 #include <corsika/framework/utility/Singleton.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 /*!
  * With this class modules can register streams of random numbers.
diff --git a/corsika/framework/stack/CombinedStack.hpp b/corsika/framework/stack/CombinedStack.hpp
index 5dfbbfe126f0025f488eab5f91babac0914d4732..d452d8f8b469f7a79317036331d3c345f4d2b15e 100644
--- a/corsika/framework/stack/CombinedStack.hpp
+++ b/corsika/framework/stack/CombinedStack.hpp
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/core/ParticleProperties.hpp>
 #include <corsika/framework/stack/Stack.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
diff --git a/corsika/framework/stack/SecondaryView.hpp b/corsika/framework/stack/SecondaryView.hpp
index 515c0f57c2a1457daf198ba7fc36ac2e30d04dbf..e18531b3154e250ab44c33014a92355e0b9a877a 100644
--- a/corsika/framework/stack/SecondaryView.hpp
+++ b/corsika/framework/stack/SecondaryView.hpp
@@ -9,7 +9,7 @@
 #pragma once
 
 #include <corsika/framework/stack/Stack.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <stdexcept>
 #include <vector>
diff --git a/corsika/framework/stack/Stack.hpp b/corsika/framework/stack/Stack.hpp
index 4a6f0905648431f7b60eb77f91acbceadea0ae1e..e72dc94dbeb304258aab5206fb7e4552474725d4 100644
--- a/corsika/framework/stack/Stack.hpp
+++ b/corsika/framework/stack/Stack.hpp
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/stack/StackIteratorInterface.hpp>
 
 #include <stdexcept>
diff --git a/corsika/framework/utility/COMBoost.hpp b/corsika/framework/utility/COMBoost.hpp
index 0d4d14ebeb96a7256a1b7c1dafdffd1ef7327a51..63b8f0a4420f258569bebcc44a2e3f361f6ba6fe 100644
--- a/corsika/framework/utility/COMBoost.hpp
+++ b/corsika/framework/utility/COMBoost.hpp
@@ -12,7 +12,7 @@
 #include <corsika/framework/geometry/FourVector.hpp>
 #include <corsika/framework/geometry/PhysicalGeometry.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <Eigen/Dense>
 
diff --git a/corsika/modules/tracking/Intersect.hpp b/corsika/modules/tracking/Intersect.hpp
index 459cef8504dbafb3e01c31836214e68dfeb809ba..1e7a07d84dbee68f4094089a23a99f15cf4fbb69 100644
--- a/corsika/modules/tracking/Intersect.hpp
+++ b/corsika/modules/tracking/Intersect.hpp
@@ -9,7 +9,7 @@
 #pragma once
 
 #include <corsika/framework/core/PhysicalUnits.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/geometry/Intersections.hpp>
 
 #include <limits>
diff --git a/corsika/modules/tracking/TrackingLeapFrogCurved.hpp b/corsika/modules/tracking/TrackingLeapFrogCurved.hpp
index 883f96dbcdb9526e83da3b2b562335c547bcc43b..dff4bc18ea42ee6ab0d399ad1b2dc7d3b9e185aa 100644
--- a/corsika/modules/tracking/TrackingLeapFrogCurved.hpp
+++ b/corsika/modules/tracking/TrackingLeapFrogCurved.hpp
@@ -18,7 +18,7 @@
 #include <corsika/framework/core/ParticleProperties.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/utility/QuarticSolver.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/modules/tracking/Intersect.hpp>
 
 #include <type_traits>
diff --git a/corsika/modules/tracking/TrackingStraight.hpp b/corsika/modules/tracking/TrackingStraight.hpp
index c595a75a5b18e27f5ab3f0467bbb3c37ee43f1b6..b77f8fd211b6c2459e012389b6fa6939088494da 100644
--- a/corsika/modules/tracking/TrackingStraight.hpp
+++ b/corsika/modules/tracking/TrackingStraight.hpp
@@ -15,7 +15,7 @@
 #include <corsika/framework/geometry/Vector.hpp>
 #include <corsika/framework/geometry/StraightTrajectory.hpp>
 #include <corsika/framework/geometry/Intersections.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/modules/tracking/Intersect.hpp>
 
 #include <type_traits>
diff --git a/corsika/stack/GeometryNodeStackExtension.hpp b/corsika/stack/GeometryNodeStackExtension.hpp
index 3450dc2ac4433c9cbf51ade1fd41b90092dbc60d..b3a15854f58af04c8bae6ceecb0ba9e25644343e 100644
--- a/corsika/stack/GeometryNodeStackExtension.hpp
+++ b/corsika/stack/GeometryNodeStackExtension.hpp
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/stack/Stack.hpp>
 
 #include <tuple>
diff --git a/corsika/stack/history/Event.hpp b/corsika/stack/history/Event.hpp
index 1a450883bb29e55c65af1edcced5f6b5dfd5361f..4ac1ccdc8107f383ff1f0788e596d6e7f64df8ad 100644
--- a/corsika/stack/history/Event.hpp
+++ b/corsika/stack/history/Event.hpp
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/core/ParticleProperties.hpp>
 #include <corsika/stack/history/EventType.hpp>
 #include <corsika/stack/history/SecondaryParticle.hpp>
diff --git a/corsika/stack/history/HistorySecondaryProducer.hpp b/corsika/stack/history/HistorySecondaryProducer.hpp
index f7317a22b0c290203880af3110b07a63fb4b2379..cf7ef2e4dfddd5dc6d582b53880b7ccc56656ec6 100644
--- a/corsika/stack/history/HistorySecondaryProducer.hpp
+++ b/corsika/stack/history/HistorySecondaryProducer.hpp
@@ -11,7 +11,7 @@
 #include <corsika/framework/stack/SecondaryView.hpp>
 #include <corsika/stack/history/Event.hpp>
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <boost/type_index.hpp>
 
diff --git a/corsika/stack/history/HistoryStackExtension.hpp b/corsika/stack/history/HistoryStackExtension.hpp
index 2d79af4c4fa12a009a019e1fe27e576e130a184c..9d517b0acae18d541be59f86d3540238a28b8c9a 100644
--- a/corsika/stack/history/HistoryStackExtension.hpp
+++ b/corsika/stack/history/HistoryStackExtension.hpp
@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/stack/Stack.hpp>
 
 #include <memory>
diff --git a/examples/boundary_example.cpp b/examples/boundary_example.cpp
index a45a9af898c787e0ebaf73236ce550e80d701515..da4d76d3ec750eb1a22d84cca470fec95c0644e7 100644
--- a/examples/boundary_example.cpp
+++ b/examples/boundary_example.cpp
@@ -12,7 +12,7 @@
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/random/RNGManager.hpp>
 #include <corsika/framework/utility/CorsikaFenv.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/setup/SetupEnvironment.hpp>
 #include <corsika/setup/SetupStack.hpp>
diff --git a/examples/cascade_example.cpp b/examples/cascade_example.cpp
index 171990459d5cc77b75cadc7dcc42fdae10de3e58..65366853f67a44c0ccd5096c94872eac00d533d6 100644
--- a/examples/cascade_example.cpp
+++ b/examples/cascade_example.cpp
@@ -13,7 +13,7 @@
 #include <corsika/framework/geometry/Sphere.hpp>
 
 #include <corsika/framework/utility/CorsikaFenv.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/media/Environment.hpp>
 #include <corsika/media/HomogeneousMedium.hpp>
diff --git a/examples/cascade_proton_example.cpp b/examples/cascade_proton_example.cpp
index 554d50532b2e1190964813c12551bbe713ccf926..d7ed42c341d0a100661cf392aa009652a638c925 100644
--- a/examples/cascade_proton_example.cpp
+++ b/examples/cascade_proton_example.cpp
@@ -13,7 +13,7 @@
 #include <corsika/framework/geometry/Sphere.hpp>
 
 #include <corsika/framework/utility/CorsikaFenv.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/media/Environment.hpp>
 #include <corsika/media/HomogeneousMedium.hpp>
diff --git a/examples/em_shower.cpp b/examples/em_shower.cpp
index f34df8b54ed64c30d2a6fd2cd7421613e2c75f72..4bd457b8d53c0351a9cdf3fc50f9a9681a934f6d 100644
--- a/examples/em_shower.cpp
+++ b/examples/em_shower.cpp
@@ -15,7 +15,7 @@
 #include <corsika/framework/core/PhysicalUnits.hpp>
 #include <corsika/framework/utility/CorsikaFenv.hpp>
 #include <corsika/framework/process/InteractionCounter.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <corsika/media/Environment.hpp>
 #include <corsika/media/LayeredSphericalAtmosphereBuilder.hpp>
diff --git a/examples/geometry_example.cpp b/examples/geometry_example.cpp
index 8c471cb6040d2e2f91866625c730e97a7fe1f302..b752d52ca16577e28a78a3b47fd74ee524263d22 100644
--- a/examples/geometry_example.cpp
+++ b/examples/geometry_example.cpp
@@ -11,7 +11,7 @@
 #include <corsika/framework/geometry/Sphere.hpp>
 #include <corsika/framework/geometry/Vector.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <cstdlib>
 #include <typeinfo>
diff --git a/examples/hybrid_MC.cpp b/examples/hybrid_MC.cpp
index 7ff8daa6f3702da70a2a4aea6c0859044f8d82ca..410c5bf1c8777891e48c3a40c9b2715fdc6af027 100644
--- a/examples/hybrid_MC.cpp
+++ b/examples/hybrid_MC.cpp
@@ -14,7 +14,7 @@
 /* clang-format on */
 #include <corsika/framework/geometry/Plane.hpp>
 #include <corsika/framework/geometry/Sphere.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/process/ProcessSequence.hpp>
 #include <corsika/framework/process/SwitchProcessSequence.hpp>
 #include <corsika/framework/process/InteractionCounter.hpp>
diff --git a/examples/stack_example.cpp b/examples/stack_example.cpp
index 196efa5c9c4da716cc54efda52de6fcc697f5f27..277b6876081e6d537cbbf5d7b0b5f6db1b0efed7 100644
--- a/examples/stack_example.cpp
+++ b/examples/stack_example.cpp
@@ -7,7 +7,7 @@
  */
 
 #include <corsika/framework/core/ParticleProperties.hpp>
-#include <corsika/stack/SimpleStack.hpp>
+#include <corsika/stack/VectorStack.hpp>
 
 #include <corsika/framework/geometry/Point.hpp>
 #include <corsika/framework/geometry/RootCoordinateSystem.hpp>
@@ -19,7 +19,7 @@
 using namespace corsika;
 using namespace std;
 
-void fill(SimpleStack& s) {
+void fill(VectorStack& s) {
   CoordinateSystemPtr const& rootCS = get_root_CoordinateSystem();
   for (int i = 0; i < 11; ++i) {
     s.addParticle(std::make_tuple(Code::Electron, 1.5_GeV * i,
@@ -28,7 +28,7 @@ void fill(SimpleStack& s) {
   }
 }
 
-void read(SimpleStack& s) {
+void read(VectorStack& s) {
   assert(s.getEntries() == 11); // stack has 11 particles
 
   HEPEnergyType total_energy;
@@ -44,7 +44,7 @@ void read(SimpleStack& s) {
 int main() {
 
   std::cout << "stack_example" << std::endl;
-  SimpleStack s;
+  VectorStack s;
   fill(s);
   read(s);
   return 0;
diff --git a/examples/vertical_EAS.cpp b/examples/vertical_EAS.cpp
index 44e7b865b19bab0cb476083a4f5c432f257c3930..9dfbfb11dba2a1d597199f6746ea04898455e4fb 100644
--- a/examples/vertical_EAS.cpp
+++ b/examples/vertical_EAS.cpp
@@ -14,7 +14,7 @@
 /* clang-format on */
 #include <corsika/framework/geometry/Plane.hpp>
 #include <corsika/framework/geometry/Sphere.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 #include <corsika/framework/process/ProcessSequence.hpp>
 #include <corsika/framework/process/SwitchProcessSequence.hpp>
 #include <corsika/framework/process/InteractionCounter.hpp>
diff --git a/tests/framework/testLogging.cpp b/tests/framework/testLogging.cpp
index 0d55c425979e8256cc6f160300734cfbb3b759e7..9c06a18fa59285ac960b56bd7dfc2bec8a6c6eed 100644
--- a/tests/framework/testLogging.cpp
+++ b/tests/framework/testLogging.cpp
@@ -6,7 +6,7 @@
  * the license.
  */
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <catch2/catch.hpp>
 
diff --git a/tests/framework/testSecondaryView.cpp b/tests/framework/testSecondaryView.cpp
index a2a161bd816ab026d67d9b2fff27026325e2c852..db14cdd8a28803458f6fc4599acc98a44377e953 100644
--- a/tests/framework/testSecondaryView.cpp
+++ b/tests/framework/testSecondaryView.cpp
@@ -10,7 +10,7 @@
 
 #include <corsika/framework/stack/SecondaryView.hpp>
 #include <corsika/framework/stack/Stack.hpp>
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <testTestStack.hpp> // for testing: simple stack. This is a
 // test-build, and inluce file is obtained from CMAKE_CURRENT_SOURCE_DIR
diff --git a/tests/stack/CMakeLists.txt b/tests/stack/CMakeLists.txt
index ffb63562456ee171f78374e6f0e9e8c3fdc7486f..8fe1070f199e6cf0ca529d267b6189dc6a990cc6 100644
--- a/tests/stack/CMakeLists.txt
+++ b/tests/stack/CMakeLists.txt
@@ -4,7 +4,7 @@ set (test_stack_sources
   testHistoryView.cpp
   testGeometryNodeStackExtension.cpp
   testDummyStack.cpp
-  testSimpleStack.cpp
+  testVectorStack.cpp
   testNuclearStackExtension.cpp
   )
 
diff --git a/tests/stack/testHistoryView.cpp b/tests/stack/testHistoryView.cpp
index 284cbf7ebad93dfd9161f73938308f32c9cb651e..ce09e81e3ff0316f7f4bcbf263f7c85d8989eb62 100644
--- a/tests/stack/testHistoryView.cpp
+++ b/tests/stack/testHistoryView.cpp
@@ -14,7 +14,7 @@
 #include <corsika/stack/DummyStack.hpp>
 #include <corsika/stack/NuclearStackExtension.hpp>
 
-#include <corsika/framework/logging/Logging.hpp>
+#include <corsika/framework/core/Logging.hpp>
 
 #include <catch2/catch.hpp>
 
diff --git a/tests/stack/testNuclearStackExtension.cpp b/tests/stack/testNuclearStackExtension.cpp
index 13a3ec18c913167abced05f857a03547d1a87a1e..c00fb2fe652668a6b77c1e16330253a236f336c1 100644
--- a/tests/stack/testNuclearStackExtension.cpp
+++ b/tests/stack/testNuclearStackExtension.cpp
@@ -22,7 +22,7 @@ TEST_CASE("NuclearStackExtension", "[stack]") {
   CoordinateSystemPtr const& dummyCS = get_root_CoordinateSystem();
 
   SECTION("write non nucleus") {
-    nuclear_stack::NuclearStackExtension<SimpleStack,
+    nuclear_stack::NuclearStackExtension<VectorStack,
                                          nuclear_stack::ExtendedParticleInterfaceType>
         s;
     s.addParticle(std::make_tuple(
@@ -33,7 +33,7 @@ TEST_CASE("NuclearStackExtension", "[stack]") {
 
   SECTION("write nucleus") {
 
-    nuclear_stack::NuclearStackExtension<SimpleStack,
+    nuclear_stack::NuclearStackExtension<VectorStack,
                                          nuclear_stack::ExtendedParticleInterfaceType>
         s;
     s.addParticle(std::make_tuple(
@@ -212,7 +212,7 @@ TEST_CASE("NuclearStackExtension", "[stack]") {
 
   SECTION("not allowed") {
 
-    nuclear_stack::NuclearStackExtension<SimpleStack,
+    nuclear_stack::NuclearStackExtension<VectorStack,
                                          nuclear_stack::ExtendedParticleInterfaceType>
         s;
 
diff --git a/tests/stack/testSimpleStack.cpp b/tests/stack/testVectorStack.cpp
similarity index 92%
rename from tests/stack/testSimpleStack.cpp
rename to tests/stack/testVectorStack.cpp
index 7aa7643597ad1e0308ba70ce751d5bfb65c28f34..420a0232ab1960667c36ec5acb08581be4d20312 100644
--- a/tests/stack/testSimpleStack.cpp
+++ b/tests/stack/testVectorStack.cpp
@@ -9,7 +9,7 @@
 #define protected public // to also test the internal state of objects
 
 #include <corsika/framework/geometry/RootCoordinateSystem.hpp>
-#include <corsika/stack/SimpleStack.hpp>
+#include <corsika/stack/VectorStack.hpp>
 #include <corsika/framework/core/PhysicalUnits.hpp>
 
 #include <catch2/catch.hpp>
@@ -17,13 +17,13 @@
 using namespace corsika;
 using namespace std;
 
-TEST_CASE("SimpleStack", "[stack]") {
+TEST_CASE("VectorStack", "[stack]") {
 
   const CoordinateSystemPtr& dummyCS = get_root_CoordinateSystem();
 
   SECTION("read+write") {
 
-    SimpleStack s;
+    VectorStack s;
     s.addParticle(std::make_tuple(
         Code::Electron, 1.5_GeV, MomentumVector(dummyCS, {1_GeV, 1_GeV, 1_GeV}),
         Point(dummyCS, {1 * meter, 1 * meter, 1 * meter}), 100_s));
@@ -39,7 +39,7 @@ TEST_CASE("SimpleStack", "[stack]") {
 
   SECTION("write+delete") {
 
-    SimpleStack s;
+    VectorStack s;
     for (int i = 0; i < 99; ++i)
 
       s.addParticle(std::make_tuple(
diff --git a/corsika/stack/NuclearStackExtension.hpp b/corsika/stack/NuclearStackExtension.hpp
index bcd187c05f2d525fb56833897c3284ab9132c98b..5d8d573ed35b35b79fa6770461c922c61150a1ea 100644
--- a/corsika/stack/NuclearStackExtension.hpp
+++ b/corsika/stack/NuclearStackExtension.hpp
@@ -14,7 +14,7 @@
 #include <corsika/framework/geometry/Point.hpp>
 #include <corsika/framework/geometry/Vector.hpp>
 #include <corsika/framework/geometry/PhysicalGeometry.hpp>
-#include <corsika/stack/SimpleStack.hpp>
+#include <corsika/stack/VectorStack.hpp>
 
 #include <algorithm>
 #include <tuple>
@@ -27,7 +27,7 @@ namespace corsika::nuclear_stack {
    * Define ParticleInterface for NuclearStackExtension Stack derived from
    * ParticleInterface of Inner stack class
    *
    * Add A and Z data to existing stack (currently SimpleStack) of particle
    * properties. This is done via inheritance, not via CombinedStack since the nuclear
    * data is stored ONLY when needed (for nuclei) and not for all particles. Thus, this is
    * a new, derived Stack object.
@@ -210,11 +210,11 @@ namespace corsika::nuclear_stack {
   //
   template <typename TStackIter>
   using ExtendedParticleInterfaceType =
-      NuclearParticleInterface<SimpleStack::pi_type, TStackIter>;
+      NuclearParticleInterface<VectorStack::pi_type, TStackIter>;
 
   // the particle data stack with extra nuclear information:
   using ParticleDataStack =
-      NuclearStackExtension<SimpleStack, ExtendedParticleInterfaceType>;
+      NuclearStackExtension<VectorStack, ExtendedParticleInterfaceType>;
 
 } // namespace corsika::nuclear_stack
 
@@ -27,7 +27,7 @@ namespace corsika::nuclear_stack {
    * ParticleInterface of Inner stack class
    *
-   * Add A and Z data to existing stack (currently SimpleStack) of particle
+   * Add A and Z data to existing stack (currently VectorStack) of particle
    * properties. This is done via inheritance, not via CombinedStack since the nuclear
    * data is stored ONLY when needed (for nuclei) and not for all particles. Thus, this is
diff --git a/corsika/stack/SimpleStack.hpp b/corsika/stack/VectorStack.hpp
similarity index 91%
rename from corsika/stack/SimpleStack.hpp
rename to corsika/stack/VectorStack.hpp
index 57c3c2ee3180c646901af3b470dcf05f661efdad..7877469ee39fa4d3f8f3326bd56c112e61da0267 100644
--- a/corsika/stack/SimpleStack.hpp
+++ b/corsika/stack/VectorStack.hpp
@@ -98,7 +98,7 @@ namespace corsika {
    *
    */
 
-  class SimpleStackImpl {
+  class VectorStackImpl {
 
   public:
     typedef std::vector<Code> code_vector_type;
@@ -107,15 +107,15 @@ namespace corsika {
     typedef std::vector<TimeType> time_vector_type;
     typedef std::vector<MomentumVector> momentum_vector_type;
 
-    SimpleStackImpl() = default;
+    VectorStackImpl() = default;
 
-    SimpleStackImpl(SimpleStackImpl const& other) = default;
+    VectorStackImpl(VectorStackImpl const& other) = default;
 
-    SimpleStackImpl(SimpleStackImpl&& other) = default;
+    VectorStackImpl(VectorStackImpl&& other) = default;
 
-    SimpleStackImpl& operator=(SimpleStackImpl const& other) = default;
+    VectorStackImpl& operator=(VectorStackImpl const& other) = default;
 
-    SimpleStackImpl& operator=(SimpleStackImpl&& other) = default;
+    VectorStackImpl& operator=(VectorStackImpl&& other) = default;
 
     void dump() const {}
 
@@ -167,10 +167,10 @@ namespace corsika {
     point_vector_type position_;
     time_vector_type time_;
 
-  }; // end class SimpleStackImpl
+  }; // end class VectorStackImpl
 
-  typedef Stack<SimpleStackImpl, ParticleInterface> SimpleStack;
+  typedef Stack<VectorStackImpl, ParticleInterface> VectorStack;
 
 } // namespace corsika
 
-#include <corsika/detail/stack/SimpleStack.inl>
+#include <corsika/detail/stack/VectorStack.inl>